import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";
import "./globals.css";
import Header from "@/components/Header/Header";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "Nomvate - Educational Game Platform by EdvoLab",
  description: "Engage in interactive educational games designed to enhance learning through play. Experience unique challenges, multiplayer competitions, and educational content curated by EdvoLab.",
  keywords: "educational games, learning platform, EdvoLab, interactive learning, educational technology, game-based learning, multiplayer educational games",
  authors: [{ name: "EdvoLab Team" }],
  creator: "EdvoLab",
  publisher: "EdvoLab",
  formatDetection: {
    email: false,
    address: false,
    telephone: false,
  },
  icons: {
    icon: [
      { url: '/edvolab_logo.png' },
      { url: '/edvolab_logo.png', type: 'image/png' },
    ],
    apple: [
      { url: '/edvolab_logo.png', sizes: '180x180' },
    ],
  },
  manifest: '/manifest.json',
  viewport: {
    width: 'device-width',
    initialScale: 1,
    maximumScale: 1,
  },
  robots: {
    index: true,
    follow: true,
    googleBot: {
      index: true,
      follow: true,
      'max-video-preview': -1,
      'max-image-preview': 'large',
      'max-snippet': -1,
    },
  },
  openGraph: {
    type: 'website',
    locale: 'en_US',
    url: 'https://nomvate.edvolab.com/',
    siteName: 'Nomvate',
    title: 'Nomvate - Educational Game Platform by EdvoLab',
    description: 'Engage in interactive educational games designed to enhance learning through play. Experience unique challenges, multiplayer competitions, and educational content curated by EdvoLab.',
    images: [
      {
        url: '/og-image.png',
        width: 1200,
        height: 630,
        alt: 'Nomvate Platform Preview',
      },
    ],
  },
  twitter: {
    card: 'summary_large_image',
    title: 'Nomvate - Educational Game Platform by EdvoLab',
    description: 'Engage in interactive educational games designed to enhance learning through play.',
    creator: '@edvolab',
    images: ['/twitter-image.png'],
  },
  verification: {
    google: 'your-google-site-verification',
  },
  category: 'education',
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <head>
        <link rel="icon" href="/edvolab_logo.png" />
        <link rel="apple-touch-icon" href="/edvolab_logo.png" />
        <link rel="manifest" href="/manifest.json" />
      </head>
      <body
        className={`${geistSans.variable} ${geistMono.variable} antialiased`}
      >
        <Header />
        <main className="pt-16">
          {children}
        </main>
      </body>
    </html>
  );
}
